@@ -1,5 +1,5 @@
 /**
- * @file default_param_impl.hpp
+ * @file bindings/cli/default_param_impl.hpp
  * @author Ryan Curtin
  *
  * Return the default value of a parameter, depending on its type.
@@ -32,7 +32,9 @@ std::string DefaultParamImpl(
         std::tuple<mlpack::data::DatasetInfo, arma::mat>>>::type* /* junk */)
 {
   std::ostringstream oss;
-  oss << boost::any_cast<T>(data.value);
+  if (!std::is_same<T, bool>::value)
+    oss << boost::any_cast<T>(data.value);
+
   return oss.str();
 }
 
@@ -48,9 +50,35 @@ std::string DefaultParamImpl(
   std::ostringstream oss;
   const T& vector = boost::any_cast<T>(data.value);
   oss << "[";
-  for (size_t i = 0; i < vector.size() - 1; ++i)
-    oss << vector[i] << " ";
-  oss << vector[vector.size() - 1] << "]";
+  if (std::is_same<T, std::vector<std::string>>::value)
+  {
+    if (vector.size() > 0)
+    {
+      for (size_t i = 0; i < vector.size() - 1; ++i)
+      {
+        oss << "'" << vector[i] << "', ";
+      }
+
+      oss << "'" << vector[vector.size() - 1] << "'";
+    }
+
+    oss << "]";
+  }
+  else
+  {
+    if (vector.size() > 0)
+    {
+      for (size_t i = 0; i < vector.size() - 1; ++i)
+      {
+        oss << vector[i] << ", ";
+      }
+
+      oss << vector[vector.size() - 1];
+    }
+
+    oss << "]";
+  }
+
   return oss.str();
 }
 
@@ -67,39 +95,30 @@ std::string DefaultParamImpl(
 }
 
 /**
- * Return the default value of a matrix option (this returns the default
- * filename, or '' if the default is no file).
+ * Return the default value of a matrix option (an empty filename).
  */
 template<typename T>
 std::string DefaultParamImpl(
-    const util::ParamData& data,
+    const util::ParamData& /* data */,
     const typename boost::enable_if_c<
         arma::is_arma_type<T>::value ||
         std::is_same<T, std::tuple<mlpack::data::DatasetInfo,
                                    arma::mat>>::value>::type* /* junk */)
 {
-  // Get the filename and return it, or return an empty string.
-  typedef std::tuple<T, std::string> TupleType;
-  const TupleType& tuple = *boost::any_cast<TupleType>(&data.value);
-  const std::string& filename = std::get<1>(tuple);
-  return "'" + filename + "'";
+  // The filename will always be empty.
+  return "''";
 }
 
 /**
- * Return the default value of a model option (this returns the default
- * filename, or '' if the default is no file).
+ * Return the default value of a model option (an empty filename).
  */
 template<typename T>
 std::string DefaultParamImpl(
-    const util::ParamData& data,
+    const util::ParamData& /* data */,
     const typename boost::disable_if<arma::is_arma_type<T>>::type* /* junk */,
     const typename boost::enable_if<data::HasSerialize<T>>::type* /* junk */)
 {
-  // Get the filename and return it, or return an empty string.
-  typedef std::tuple<T*, std::string> TupleType;
-  const TupleType& tuple = *boost::any_cast<TupleType>(&data.value);
-  const std::string& filename = std::get<1>(tuple);
-  return "'" + filename + "'";
+  return "''";
 }
 
 
