@@ -1,5 +1,5 @@
 /**
- * @file string_type_param.hpp
+ * @file bindings/cli/string_type_param.hpp
  * @author Ryan Curtin
  *
  * Given a util::ParamData object, return a string containing the type of the input
@@ -74,12 +74,6 @@ inline void StringTypeParam<std::string>(const util::ParamData& /* data */,
                                          const void* /* input */,
                                          void* output);
 
-//! Return "float".
-template<>
-inline void StringTypeParam<float>(const util::ParamData& /* data */,
-                                   const void* /* input */,
-                                   void* output);
-
 //! Return "double".
 template<>
 inline void StringTypeParam<double>(const util::ParamData& /* data */,
