@@ -1,5 +1,5 @@
 /**
- * @file print_doc_functions_impl.hpp
+ * @file bindings/julia/print_doc_functions_impl.hpp
  * @author Ryan Curtin
  *
  * This file contains functions useful for printing documentation strings
@@ -45,6 +45,14 @@ inline std::string PrintOutputOptionInfo()
       "ignored with the _ keyword.";
 }
 
+/**
+ * Print any special information about input options.
+ */
+inline std::string PrintInputOptionInfo()
+{
+  return "";
+}
+
 /**
  * Given a parameter type, print the corresponding value.
  */
