@@ -1,5 +1,5 @@
 /**
- * @file get_binding_name.cpp
+ * @file bindings/markdown/get_binding_name.cpp
  * @author Ryan Curtin
  *
  * Given the name of a binding as it appears in CMake, return the corresponding
@@ -37,6 +37,11 @@ std::string GetBindingName(const std::string& language,
     // For Julia bindings, the name is unchanged.
     return name;
   }
+  else if (language == "go")
+  {
+    // For Go bindings, the name is unchanged.
+    return name;
+  }
   else
   {
     throw std::invalid_argument("Don't know how to compute binding name for "
