@@ -1,5 +1,5 @@
 /**
- * @file get_printable_type.hpp
+ * @file bindings/markdown/get_printable_type.hpp
  * @author Ryan Curtin
  *
  * Get the printable type of the parameter.  This depends on
@@ -18,6 +18,7 @@
 #include <mlpack/bindings/cli/get_printable_type.hpp>
 #include <mlpack/bindings/python/get_printable_type.hpp>
 #include <mlpack/bindings/julia/get_printable_type.hpp>
+#include <mlpack/bindings/go/get_printable_type.hpp>
 
 namespace mlpack {
 namespace bindings {
@@ -47,6 +48,11 @@ void GetPrintableType(const util::ParamData& data,
     *((std::string*) output) =
         julia::GetPrintableType<typename std::remove_pointer<T>::type>(data);
   }
+  else if (BindingInfo::Language() == "go")
+  {
+    *((std::string*) output) =
+        go::GetPrintableType<typename std::remove_pointer<T>::type>(data);
+  }
   else
   {
     throw std::invalid_argument("GetPrintableType(): unknown "
