@@ -1,5 +1,5 @@
 /**
- * @file print_doc_functions_impl.hpp
+ * @file bindings/markdown/print_doc_functions_impl.hpp
  * @author Ryan Curtin
  *
  * Calls out to different printing functionality for different binding languages.
@@ -21,6 +21,7 @@
 #include <mlpack/bindings/cli/print_doc_functions.hpp>
 #include <mlpack/bindings/python/print_doc_functions.hpp>
 #include <mlpack/bindings/julia/print_doc_functions.hpp>
+#include <mlpack/bindings/go/print_doc_functions.hpp>
 
 namespace mlpack {
 namespace bindings {
@@ -44,6 +45,10 @@ inline std::string GetBindingName(const std::string& bindingName)
   {
     return julia::GetBindingName(bindingName);
   }
+  else if (BindingInfo::Language() == "go")
+  {
+    return go::GetBindingName(bindingName);
+  }
   else
   {
     throw std::invalid_argument("PrintValue(): unknown "
@@ -68,6 +73,10 @@ inline std::string PrintLanguage(const std::string& language)
   {
     return "Julia";
   }
+  else if (language == "go")
+  {
+    return "Go";
+  }
   else
   {
     throw std::invalid_argument("PrintLanguage(): unknown "
@@ -92,6 +101,10 @@ inline std::string PrintImport(const std::string& bindingName)
   {
     return julia::PrintImport(bindingName);
   }
+  else if (BindingInfo::Language() == "go")
+  {
+    return go::PrintImport();
+  }
   else
   {
     throw std::invalid_argument("PrintImport(): unknown "
@@ -99,6 +112,34 @@ inline std::string PrintImport(const std::string& bindingName)
   }
 }
 
+/**
+ * Print any special information about input options.
+ */
+inline std::string PrintInputOptionInfo()
+{
+  if (BindingInfo::Language() == "cli")
+  {
+    return cli::PrintInputOptionInfo();
+  }
+  else if (BindingInfo::Language() == "python")
+  {
+    return python::PrintInputOptionInfo();
+  }
+  else if (BindingInfo::Language() == "julia")
+  {
+    return julia::PrintInputOptionInfo();
+  }
+  else if (BindingInfo::Language() == "go")
+  {
+    return go::PrintInputOptionInfo();
+  }
+  else
+  {
+    throw std::invalid_argument("PrintInputOptionInfo(): unknown "
+        "BindingInfo::Language(): " + BindingInfo::Language() + "!");
+  }
+}
+
 /**
  * Print any special information about output options.
  */
@@ -116,6 +157,10 @@ inline std::string PrintOutputOptionInfo()
   {
     return julia::PrintOutputOptionInfo();
   }
+  else if (BindingInfo::Language() == "go")
+  {
+    return go::PrintOutputOptionInfo();
+  }
   else
   {
     throw std::invalid_argument("PrintOutputOptionInfo(): unknown "
@@ -341,6 +386,10 @@ inline std::string PrintValue(const T& value, bool quotes)
   {
     result = julia::PrintValue(value, quotes);
   }
+  else if (BindingInfo::Language() == "go")
+  {
+    result = go::PrintValue(value, quotes);
+  }
   else
   {
     throw std::invalid_argument("PrintValue(): unknown "
@@ -380,6 +429,10 @@ inline std::string PrintDefault(const std::string& paramName)
     {
       oss << julia::PrintDefault(paramName);
     }
+    else if (BindingInfo::Language() == "go")
+    {
+      oss << go::PrintDefault(paramName);
+    }
     else
     {
       throw std::invalid_argument("PrintDefault: unknown "
@@ -408,6 +461,10 @@ inline std::string PrintDataset(const std::string& dataset)
   {
     result = julia::PrintDataset(dataset);
   }
+  else if (BindingInfo::Language() == "go")
+  {
+    result = go::PrintDataset(dataset);
+  }
   else
   {
     throw std::invalid_argument("PrintDataset(): unknown "
@@ -435,6 +492,10 @@ inline std::string PrintModel(const std::string& model)
   {
     result = julia::PrintModel(model);
   }
+  else if (BindingInfo::Language() == "go")
+  {
+    result = go::PrintModel(model);
+  }
   else
   {
     throw std::invalid_argument("PrintModel(): unknown "
@@ -468,6 +529,11 @@ std::string ProgramCall(const std::string& programName, Args... args)
     // the text in Markdown code, so we don't need to.
     s += julia::ProgramCall(programName, args...);
   }
+  else if (BindingInfo::Language() == "go")
+  {
+    s += "```go\n";
+    s += go::ProgramCall(programName, args...);
+  }
   else
   {
     throw std::invalid_argument("ProgramCall(): unknown "
@@ -510,6 +576,14 @@ inline std::string ProgramCall(const std::string& programName)
       s += "julia> " + import + "\n";
     s += julia::ProgramCall(programName);
   }
+  else if (BindingInfo::Language() == "go")
+  {
+    s += "go\n";
+    std::string import = PrintImport(GetBindingName(programName));
+    if (import.size() > 0)
+      s += import + "\n";
+    s += go::ProgramCall(programName);
+  }
   else
   {
     throw std::invalid_argument("ProgramCall(): unknown "
@@ -543,6 +617,10 @@ inline std::string ParamString(const std::string& paramName)
   {
     s = julia::ParamString(paramName);
   }
+  else if (BindingInfo::Language() == "go")
+  {
+    s = go::ParamString(paramName);
+  }
   else
   {
     throw std::invalid_argument("ParamString(): unknown "
@@ -586,6 +664,10 @@ inline bool IgnoreCheck(const T& t)
   {
     return julia::IgnoreCheck(t);
   }
+  else if (BindingInfo::Language() == "go")
+  {
+    return go::IgnoreCheck(t);
+  }
   else
   {
     throw std::invalid_argument("IgnoreCheck(): unknown "
