@@ -53,7 +53,7 @@
  *  - @ref sample
  *  - @ref sample_ml_app
  *  - @ref cv
- *  - @ref hpt
+ *  - @ref hpt_guide
  *  - @ref verinfo
  *
  * @section remarks Final Remarks
@@ -88,6 +88,8 @@
 #include <mlpack/core/dists/laplace_distribution.hpp>
 #include <mlpack/core/dists/gamma_distribution.hpp>
 #include <mlpack/core/dists/diagonal_gaussian_distribution.hpp>
+#include <mlpack/core/data/confusion_matrix.hpp>
+#include <mlpack/core/data/one_hot_encoding.hpp>
 
 // mlpack::backtrace only for linux
 #ifdef HAS_BFD_DL
