@@ -1,5 +1,5 @@
 /**
- * @file load.hpp
+ * @file core/data/load.hpp
  * @author Ryan Curtin
  *
  * Load an Armadillo matrix from file.  This is necessary because Armadillo does
@@ -56,7 +56,7 @@ namespace data /** Functions to load and save matrices and models. */ {
  * @param filename Name of file to load.
  * @param matrix Matrix to load contents of file into.
  * @param fatal If an error should be reported as fatal (default false).
- * @param transpose If true, transpose the matrix after loading.
+ * @param transpose If true, transpose the matrix after loading (default true).
  * @return Boolean value indicating success or failure of load.
  */
 template<typename eT>
@@ -65,6 +65,41 @@ bool Load(const std::string& filename,
           const bool fatal = false,
           const bool transpose = true);
 
+/**
+ * Loads a sparse matrix from file, using arma::coord_ascii format.  This
+ * will transpose the matrix at load time (unless the transpose parameter is set
+ * to false).  If the filetype cannot be determined, an error will be given.
+ *
+ * The supported types of files are the same as found in Armadillo:
+ *
+ *  - TSV (coord_ascii), denoted by .tsv or .txt
+ *  - TXT (coord_ascii), denoted by .txt
+ *  - Raw binary (raw_binary), denoted by .bin
+ *  - Armadillo binary (arma_binary), denoted by .bin
+ *
+ * If the file extension is not one of those types, an error will be given.
+ * This is preferable to Armadillo's default behavior of loading an unknown
+ * filetype as raw_binary, which can have very confusing effects.
+ *
+ * If the parameter 'fatal' is set to true, a std::runtime_error exception will
+ * be thrown if the matrix does not load successfully.  The parameter
+ * 'transpose' controls whether or not the matrix is transposed after loading.
+ * In most cases, because data is generally stored in a row-major format and
+ * mlpack requires column-major matrices, this should be left at its default
+ * value of 'true'.
+ *
+ * @param filename Name of file to load.
+ * @param matrix Sparse matrix to load contents of file into.
+ * @param fatal If an error should be reported as fatal (default false).
+ * @param transpose If true, transpose the matrix after loading (default true).
+ * @return Boolean value indicating success or failure of load.
+ */
+template<typename eT>
+bool Load(const std::string& filename,
+          arma::SpMat<eT>& matrix,
+          const bool fatal = false,
+          const bool transpose = true);
+
 /**
  * Don't document these with doxygen; these declarations aren't helpful to
  * users.
@@ -103,6 +138,36 @@ extern template bool Load<double>(const std::string&,
                                   const bool,
                                   const bool);
 
+extern template bool Load<int>(const std::string&,
+                               arma::Mat<int>&,
+                               const bool,
+                               const bool);
+
+extern template bool Load<unsigned int>(const std::string&,
+                                        arma::SpMat<unsigned int>&,
+                                        const bool,
+                                        const bool);
+
+extern template bool Load<unsigned long>(const std::string&,
+                                         arma::SpMat<unsigned long>&,
+                                         const bool,
+                                         const bool);
+
+extern template bool Load<unsigned long long>(const std::string&,
+                                              arma::SpMat<unsigned long long>&,
+                                              const bool,
+                                              const bool);
+
+extern template bool Load<float>(const std::string&,
+                                 arma::SpMat<float>&,
+                                 const bool,
+                                 const bool);
+
+extern template bool Load<double>(const std::string&,
+                                  arma::SpMat<double>&,
+                                  const bool,
+                                  const bool);
+
 /**
  * @endcond
  */
@@ -130,7 +195,7 @@ extern template bool Load<double>(const std::string&,
  * be thrown if the matrix does not load successfully.
  *
  * @param filename Name of file to load.
- * @param colvec Column vector to load contents of file into.
+ * @param vec Column vector to load contents of file into.
  * @param fatal If an error should be reported as fatal (default false).
  * @return Boolean value indicating success or failure of load.
  */
@@ -162,7 +227,7 @@ bool Load(const std::string& filename,
  * be thrown if the matrix does not load successfully.
  *
  * @param filename Name of file to load.
- * @param colvec Column vector to load contents of file into.
+ * @param rowvec Row vector to load contents of file into.
  * @param fatal If an error should be reported as fatal (default false).
  * @return Boolean value indicating success or failure of load.
  */
@@ -314,7 +379,6 @@ bool Load(const std::string& filename,
  * @param matrix Matrix to save the image from.
  * @param info An object of ImageInfo class.
  * @param fatal If an error should be reported as fatal (default false).
- * @param transpose If true, transpose the matrix after loading.
  * @return Boolean value indicating success or failure of load.
  */
 template<typename eT>
