@@ -1,5 +1,5 @@
 /**
- * @file layer_types.hpp
+ * @file methods/ann/layer/layer_types.hpp
  * @author Marcus Edel
  *
  * This provides a list of all modules that can be used to construct a model.
@@ -36,15 +36,20 @@
 #include <mlpack/methods/ann/layer/multiply_constant.hpp>
 #include <mlpack/methods/ann/layer/max_pooling.hpp>
 #include <mlpack/methods/ann/layer/mean_pooling.hpp>
+#include <mlpack/methods/ann/layer/noisylinear.hpp>
+#include <mlpack/methods/ann/layer/adaptive_max_pooling.hpp>
+#include <mlpack/methods/ann/layer/adaptive_mean_pooling.hpp>
 #include <mlpack/methods/ann/layer/parametric_relu.hpp>
 #include <mlpack/methods/ann/layer/reinforce_normal.hpp>
 #include <mlpack/methods/ann/layer/reparametrization.hpp>
 #include <mlpack/methods/ann/layer/select.hpp>
+#include <mlpack/methods/ann/layer/softmax.hpp>
 #include <mlpack/methods/ann/layer/subview.hpp>
 #include <mlpack/methods/ann/layer/virtual_batch_norm.hpp>
 #include <mlpack/methods/ann/layer/hardshrink.hpp>
 #include <mlpack/methods/ann/layer/celu.hpp>
 #include <mlpack/methods/ann/layer/softshrink.hpp>
+#include <mlpack/methods/ann/layer/radial_basis_function.hpp>
 
 // Convolution modules.
 #include <mlpack/methods/ann/convolution_rules/border_modes.hpp>
@@ -76,11 +81,20 @@ template<typename InputDataType,
          typename RegularizerType>
 class Linear;
 
+template<typename InputDataType,
+         typename OutputDataType,
+         typename Activation>
+class RBF;
+
 template<typename InputDataType,
          typename OutputDataType,
          typename RegularizerType>
 class LinearNoBias;
 
+template<typename InputDataType,
+         typename OutputDataType>
+class NoisyLinear;
+
 template<typename InputDataType,
          typename OutputDataType
 >
@@ -179,7 +193,19 @@ template <typename InputDataType,
 >
 class WeightNorm;
 
+template <typename InputDataType,
+          typename OutputDataType
+>
+class AdaptiveMaxPooling;
+
+template <typename InputDataType,
+          typename OutputDataType
+>
+class AdaptiveMeanPooling;
+
 using MoreTypes = boost::variant<
+        Glimpse<arma::mat, arma::mat>*,
+        Highway<arma::mat, arma::mat>*,
         Recurrent<arma::mat, arma::mat>*,
         RecurrentAttention<arma::mat, arma::mat>*,
         ReinforceNormal<arma::mat, arma::mat>*,
@@ -189,13 +215,18 @@ using MoreTypes = boost::variant<
         Sequential<arma::mat, arma::mat, true>*,
         Subview<arma::mat, arma::mat>*,
         VRClassReward<arma::mat, arma::mat>*,
-        VirtualBatchNorm<arma::mat, arma::mat>*
+        VirtualBatchNorm<arma::mat, arma::mat>*,
+        RBF<arma::mat, arma::mat, GaussianFunction>*,
+        BaseLayer<GaussianFunction, arma::mat, arma::mat>*
 >;
 
 template <typename... CustomLayers>
 using LayerTypes = boost::variant<
+    AdaptiveMaxPooling<arma::mat, arma::mat>*,
+    AdaptiveMeanPooling<arma::mat, arma::mat>*,
     Add<arma::mat, arma::mat>*,
     AddMerge<arma::mat, arma::mat>*,
+    AlphaDropout<arma::mat, arma::mat>*,
     AtrousConvolution<NaiveConvolution<ValidConvolution>,
                       NaiveConvolution<FullConvolution>,
                       NaiveConvolution<ValidConvolution>,
@@ -203,10 +234,11 @@ using LayerTypes = boost::variant<
     BaseLayer<LogisticFunction, arma::mat, arma::mat>*,
     BaseLayer<IdentityFunction, arma::mat, arma::mat>*,
     BaseLayer<TanhFunction, arma::mat, arma::mat>*,
-    BaseLayer<RectifierFunction, arma::mat, arma::mat>*,
     BaseLayer<SoftplusFunction, arma::mat, arma::mat>*,
+    BaseLayer<RectifierFunction, arma::mat, arma::mat>*,
     BatchNorm<arma::mat, arma::mat>*,
     BilinearInterpolation<arma::mat, arma::mat>*,
+    CELU<arma::mat, arma::mat>*,
     Concat<arma::mat, arma::mat>*,
     Concatenate<arma::mat, arma::mat>*,
     ConcatPerformance<NegativeLogLikelihood<arma::mat, arma::mat>,
@@ -215,38 +247,36 @@ using LayerTypes = boost::variant<
     Convolution<NaiveConvolution<ValidConvolution>,
                 NaiveConvolution<FullConvolution>,
                 NaiveConvolution<ValidConvolution>, arma::mat, arma::mat>*,
-    TransposedConvolution<NaiveConvolution<ValidConvolution>,
-            NaiveConvolution<ValidConvolution>,
-            NaiveConvolution<ValidConvolution>, arma::mat, arma::mat>*,
+    CReLU<arma::mat, arma::mat>*,
     DropConnect<arma::mat, arma::mat>*,
     Dropout<arma::mat, arma::mat>*,
-    AlphaDropout<arma::mat, arma::mat>*,
     ELU<arma::mat, arma::mat>*,
+    FastLSTM<arma::mat, arma::mat>*,
     FlexibleReLU<arma::mat, arma::mat>*,
-    Glimpse<arma::mat, arma::mat>*,
+    GRU<arma::mat, arma::mat>*,
     HardTanH<arma::mat, arma::mat>*,
-    Highway<arma::mat, arma::mat>*,
     Join<arma::mat, arma::mat>*,
     LayerNorm<arma::mat, arma::mat>*,
     LeakyReLU<arma::mat, arma::mat>*,
-    CReLU<arma::mat, arma::mat>*,
     Linear<arma::mat, arma::mat, NoRegularizer>*,
     LinearNoBias<arma::mat, arma::mat, NoRegularizer>*,
     LogSoftMax<arma::mat, arma::mat>*,
     Lookup<arma::mat, arma::mat>*,
     LSTM<arma::mat, arma::mat>*,
-    GRU<arma::mat, arma::mat>*,
-    FastLSTM<arma::mat, arma::mat>*,
     MaxPooling<arma::mat, arma::mat>*,
     MeanPooling<arma::mat, arma::mat>*,
     MiniBatchDiscrimination<arma::mat, arma::mat>*,
     MultiplyConstant<arma::mat, arma::mat>*,
     MultiplyMerge<arma::mat, arma::mat>*,
     NegativeLogLikelihood<arma::mat, arma::mat>*,
+    NoisyLinear<arma::mat, arma::mat>*,
     Padding<arma::mat, arma::mat>*,
     PReLU<arma::mat, arma::mat>*,
+    Softmax<arma::mat, arma::mat>*,
+    TransposedConvolution<NaiveConvolution<ValidConvolution>,
+            NaiveConvolution<ValidConvolution>,
+            NaiveConvolution<ValidConvolution>, arma::mat, arma::mat>*,
     WeightNorm<arma::mat, arma::mat>*,
-    CELU<arma::mat, arma::mat>*,
     MoreTypes,
     CustomLayers*...
 >;
